@@ -219,6 +219,23 @@ func TestBreakdownConfigFile(t *testing.T) {
 	)
 }
 
+func TestBreakdownConfigFileWithUsageFile(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--config-file", path.Join(dir, "infracost.yml"),
+			"--usage-file", path.Join(dir, "infracost-usage.yml"),
+		},
+		&GoldenFileOptions{
+			IsJSON: true,
+		},
+	)
+}
+
 func TestBreakdownMultiProjectSkipPaths(t *testing.T) {
 	testName := testutil.CalcGoldenFileTestdataDirName()
 	dir := path.Join("./testdata", testName)
@@ -747,7 +764,11 @@ func TestBreakdownWithPrivateSshModulePopulatesErrors(t *testing.T) {
 			"--format",
 			"json",
 		},
-		nil,
+		&GoldenFileOptions{
+			Env: map[string]string{
+				"GIT_TERMINAL_PROMPT": "0",
+			},
+		},
 	)
 
 	res := gjson.ParseBytes(output)
