@@ -67,7 +67,7 @@ func addRunFlags(cmd *cobra.Command) {
 
 	cmd.Flags().Bool("no-cache", false, "Don't attempt to cache Terraform plans")
 
-	cmd.Flags().Bool("show-skipped", false, "List unsupported and free resources")
+	cmd.Flags().Bool("show-skipped", false, "List unsupported resources")
 
 	cmd.Flags().Bool("sync-usage-file", false, "Sync usage-file with missing resources, needs usage-file too (experimental)")
 
@@ -568,7 +568,7 @@ func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*sche
 		NoColor:       r.runCtx.Config.NoColor,
 		Indent:        "  ",
 	}
-	spinner := ui.NewSpinner(fmt.Sprintf("Retrieving usage estimates for %s from Infracost Cloud", resourceStr), spinnerOpts)
+	spinner := ui.NewSpinner(fmt.Sprintf("Retrieving usage defaults for %s from Infracost Cloud", resourceStr), spinnerOpts)
 	defer spinner.Fail()
 
 	projectPtrToUsageMap := make(map[*schema.Project]schema.UsageMap, len(projects))
@@ -717,7 +717,6 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	}
 
 	hasProjectFlags := (hasPathFlag ||
-		cmd.Flags().Changed("usage-file") ||
 		cmd.Flags().Changed("project-name") ||
 		cmd.Flags().Changed("terraform-plan-flags") ||
 		cmd.Flags().Changed("terraform-var-file") ||
@@ -727,7 +726,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	if hasConfigFile && hasProjectFlags {
 		m := "--config-file flag cannot be used with the following flags: "
-		m += "--path, --project-name, --terraform-*, --usage-file"
+		m += "--path, --project-name, --terraform-*"
 		ui.PrintUsage(cmd)
 		return errors.New(m)
 	}
@@ -776,12 +775,20 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 				p.TerraformUseState = true
 			}
 		}
+		if usageFilePath, _ := cmd.Flags().GetString("usage-file"); usageFilePath != "" {
+			for _, p := range cfg.Projects {
+				if p.UsageFile == "" {
+					p.UsageFile = usageFilePath
+				}
+			}
+		}
 	}
 
 	cfg.NoCache, _ = cmd.Flags().GetBool("no-cache")
 	cfg.Format, _ = cmd.Flags().GetString("format")
 	cfg.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 	cfg.SyncUsageFile, _ = cmd.Flags().GetBool("sync-usage-file")
+	cfg.UsageFilePath, _ = cmd.Flags().GetString("usage-file")
 
 	includeAllFields := "all"
 	validFields := []string{"price", "monthlyQuantity", "unit", "hourlyCost", "monthlyCost"}
