@@ -34,6 +34,15 @@ type AutodetectConfig struct {
 	// MaxSearchDepth configures the number of folders that Infracost should
 	// traverse to detect projects.
 	MaxSearchDepth int `yaml:"max_search_depth,omitempty" ignored:"true"`
+	// ForceProjectType is used to force the project type to be a specific value.
+	// This is useful when autodetect collides with two project types, normally
+	// Terragrunt and Terraform and we want to force the project type to be one or
+	// the other.
+	ForceProjectType string `yaml:"force_project_type,omitempty" ignored:"true"`
+	// TerraformVarFileExtensions is a list of suffixes that should be used to group terraform
+	// var files. This is useful when there are non-standard terraform var file
+	// names which use different extensions.
+	TerraformVarFileExtensions []string `yaml:"terraform_var_file_extensions,omitempty" ignored:"true"`
 }
 
 type PathOverride struct {
@@ -77,6 +86,10 @@ type Project struct {
 	TerraformBinary string `yaml:"terraform_binary,omitempty" envconfig:"TERRAFORM_BINARY"`
 	// TerraformWorkspace is an optional field used to set the Terraform workspace
 	TerraformWorkspace string `yaml:"terraform_workspace,omitempty" envconfig:"TERRAFORM_WORKSPACE"`
+	// TerraformCloudWorkspace is used to override the terraform configuration blocks workspace value.
+	TerraformCloudWorkspace string `yaml:"terraform_cloud_workspace,omitempty" envconfig:"TERRAFORM_CLOUD_WORKSPACE"`
+	// TerraformCloudOrg is used to override the terraform configuration blocks organization value.
+	TerraformCloudOrg string `yaml:"terraform_cloud_org,omitempty" envconfig:"TERRAFORM_CLOUD_ORG"`
 	// TerraformCloudHost is used to override the default app.terraform.io backend host. Only applicable for
 	// terraform cloud/enterprise users.
 	TerraformCloudHost string `yaml:"terraform_cloud_host,omitempty" envconfig:"TERRAFORM_CLOUD_HOST"`
@@ -153,6 +166,8 @@ type Config struct {
 	RootPath string
 	// ConfigFilePath defines the raw value of the `--config-file` flag provided by the user
 	ConfigFilePath string
+	// UsageFilePath defines the raw value of the `--usage-file` flag provided by the user
+	UsageFilePath string
 
 	NoCache bool `yaml:"no_cache,omitempty" ignored:"true"`
 
