@@ -8,6 +8,7 @@ import (
 	"testing"
 
 	"github.com/spf13/cobra"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -130,3 +131,42 @@ projects:
 		})
 	}
 }
+
+func TestConfig_CachePath(t *testing.T) {
+	tests := []struct {
+		name     string
+		path     string
+		expected string
+	}{
+		{
+			name:     "should return the root directory with no .infracost directory in either the root or parent directories",
+			path:     "testdata/no_cache_init",
+			expected: "testdata/no_cache_init",
+		},
+		{
+			name:     "should return the parent directory with an infracost cache in the parent directory",
+			path:     "testdata/parent_cache_path/parent/child",
+			expected: "testdata/parent_cache_path/parent",
+		},
+		{
+			name:     "should return the root directory path with an infracost cache in the root directory",
+			path:     "testdata/root_cache_path/parent/child",
+			expected: "testdata/root_cache_path/parent/child",
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			c := Config{
+				RootPath: tt.path,
+			}
+
+			actual := c.CachePath()
+			if filepath.IsAbs(actual) {
+				wd, _ := os.Getwd()
+				actual, _ = filepath.Rel(wd, actual)
+			}
+			assert.Equal(t, tt.expected, actual)
+		})
+	}
+}
