@@ -1,8 +1,8 @@
 package hcl
 
 import (
+	"bytes"
 	"fmt"
-	"os"
 	"runtime/debug"
 	"strings"
 
@@ -45,6 +45,8 @@ type Attribute struct {
 	// Verbose defines if the attribute should log verbose diagnostics messages to debug.
 	Verbose bool
 	Logger  zerolog.Logger
+	// isGraph is a flag that indicates if the attribute should be evaluated with the graph evaluation
+	isGraph bool
 	// newMock generates a mock value for the attribute if it's value is missing.
 	newMock       func(attr *Attribute) cty.Value
 	previousValue cty.Value
@@ -129,7 +131,7 @@ func (attr *Attribute) Value() cty.Value {
 
 	attr.Logger.Debug().Msg("fetching attribute value")
 	var val cty.Value
-	if os.Getenv("INFRACOST_GRAPH_EVALUATOR") == "true" {
+	if attr.isGraph {
 		val = attr.graphValue()
 	} else {
 		val = attr.value(0)
@@ -139,6 +141,63 @@ func (attr *Attribute) Value() cty.Value {
 	return val
 }
 
+// ProvidersValue retrieves the value of the attribute with special handling need for module.providers
+// blocks: Keys in the providers block are converted to literal values, then the attr.Value() is returned.
+func (attr *Attribute) ProvidersValue() cty.Value {
+	if origExpr, ok := attr.HCLAttr.Expr.(*hclsyntax.ObjectConsExpr); ok {
+		newExpr := &hclsyntax.ObjectConsExpr{}
+
+		for _, item := range origExpr.Items {
+			if origKeyExpr, ok := item.KeyExpr.(*hclsyntax.ObjectConsKeyExpr); ok {
+				key := traversalAsString(origKeyExpr.AsTraversal())
+
+				literalKey := &hclsyntax.LiteralValueExpr{
+					Val: cty.StringVal(key),
+				}
+
+				newExpr.Items = append(newExpr.Items, hclsyntax.ObjectConsItem{
+					KeyExpr:   literalKey,
+					ValueExpr: item.ValueExpr,
+				})
+			} else {
+				newExpr.Items = append(newExpr.Items, item)
+			}
+		}
+
+		attr.HCLAttr.Expr = newExpr
+	}
+
+	return attr.Value()
+}
+
+// DecodeProviders decodes the providers block into a map of provider names to provider aliases.
+// This is used by the graph evaluator to make sure the correct edges are created when providers are
+// inherited from parent modules.
+func (attr *Attribute) DecodeProviders() map[string]string {
+	providers := make(map[string]string)
+
+	if origExpr, ok := attr.HCLAttr.Expr.(*hclsyntax.ObjectConsExpr); ok {
+		for _, item := range origExpr.Items {
+			keyExpr, ok := item.KeyExpr.(*hclsyntax.ObjectConsKeyExpr)
+			if !ok {
+				continue
+			}
+
+			valExpr, ok := item.ValueExpr.(*hclsyntax.ScopeTraversalExpr)
+			if !ok {
+				continue
+			}
+
+			key := traversalAsString(keyExpr.AsTraversal())
+			val := traversalAsString(valExpr.AsTraversal())
+
+			providers[key] = val
+		}
+	}
+
+	return providers
+}
+
 // HasChanged returns if the Attribute Value has changed since Value was last called.
 func (attr *Attribute) HasChanged() (change bool) {
 	if attr == nil {
@@ -155,7 +214,7 @@ func (attr *Attribute) HasChanged() (change bool) {
 
 	previous := attr.previousValue
 	var current cty.Value
-	if os.Getenv("INFRACOST_GRAPH_EVALUATOR") == "true" {
+	if attr.isGraph {
 		current = attr.graphValue()
 	} else {
 		current = attr.value(0)
@@ -469,7 +528,7 @@ func mockExpressionCalls(expr hcl.Expression, diagnostics hcl.Diagnostics, mocke
 		}
 	case *hclsyntax.ConditionalExpr:
 		return &hclsyntax.ConditionalExpr{
-			Condition:   mockCondition(diagnostics, t.Condition, mockedVal),
+			Condition:   mockBoolExpressionCall(t.Condition, diagnostics, mockedVal),
 			TrueResult:  mockExpressionCalls(t.TrueResult, diagnostics, mockedVal),
 			FalseResult: mockExpressionCalls(t.FalseResult, diagnostics, mockedVal),
 			SrcRange:    t.SrcRange,
@@ -515,7 +574,7 @@ func mockExpressionCalls(expr hcl.Expression, diagnostics hcl.Diagnostics, mocke
 			CollExpr:   newLiteralValueCollectionExpression(mockedVal, mockExpressionCalls(t.CollExpr, diagnostics, mockedVal)),
 			KeyExpr:    mockExpressionCalls(t.KeyExpr, diagnostics, mockedVal),
 			ValExpr:    mockExpressionCalls(t.ValExpr, diagnostics, mockedVal),
-			CondExpr:   mockCondition(diagnostics, t.CondExpr, mockedVal),
+			CondExpr:   mockBoolExpressionCall(t.CondExpr, diagnostics, mockedVal),
 			Group:      t.Group,
 			SrcRange:   t.SrcRange,
 			OpenRange:  t.OpenRange,
@@ -535,16 +594,48 @@ func mockExpressionCalls(expr hcl.Expression, diagnostics hcl.Diagnostics, mocke
 			MarkerRange: t.MarkerRange,
 		}
 	case *hclsyntax.BinaryOpExpr:
+		// Logical operators (|| and &&) expect bools on both sides, so we need to mock the expression
+		// with a bool value.
+		impl := t.Op.Impl
+		params := impl.Params()
+
+		var lhsVal hclsyntax.Expression
+		var rhsVal hclsyntax.Expression
+
+		if len(params) > 0 && params[0].Type == cty.Bool {
+			lhsVal = mockBoolExpressionCall(t.LHS, diagnostics, mockedVal)
+		} else {
+			lhsVal = mockExpressionCalls(t.LHS, diagnostics, mockedVal)
+		}
+
+		if len(params) > 1 && params[1].Type == cty.Bool {
+			rhsVal = mockBoolExpressionCall(t.RHS, diagnostics, mockedVal)
+		} else {
+			rhsVal = mockExpressionCalls(t.RHS, diagnostics, mockedVal)
+		}
+
 		return &hclsyntax.BinaryOpExpr{
-			LHS:      mockExpressionCalls(t.LHS, diagnostics, mockedVal),
+			LHS:      lhsVal,
 			Op:       t.Op,
-			RHS:      mockExpressionCalls(t.RHS, diagnostics, mockedVal),
+			RHS:      rhsVal,
 			SrcRange: t.SrcRange,
 		}
 	case *hclsyntax.UnaryOpExpr:
+		// The ! operator expects a bool on the right side, so we need to mock the expression
+		// with a bool value.
+		impl := t.Op.Impl
+		params := impl.Params()
+
+		var val hclsyntax.Expression
+		if len(params) > 0 && params[0].Type == cty.Bool {
+			val = mockBoolExpressionCall(t.Val, diagnostics, mockedVal)
+		} else {
+			val = mockExpressionCalls(t.Val, diagnostics, mockedVal)
+		}
+
 		return &hclsyntax.UnaryOpExpr{
 			Op:          t.Op,
-			Val:         mockExpressionCalls(t.Val, diagnostics, mockedVal),
+			Val:         val,
 			SrcRange:    t.SrcRange,
 			SymbolRange: t.SymbolRange,
 		}
@@ -600,7 +691,7 @@ func mockExpressionCalls(expr hcl.Expression, diagnostics hcl.Diagnostics, mocke
 	}
 }
 
-func mockCondition(diagnostics hcl.Diagnostics, expression hclsyntax.Expression, mockedVal cty.Value) hclsyntax.Expression {
+func mockBoolExpressionCall(expression hclsyntax.Expression, diagnostics hcl.Diagnostics, mockedVal cty.Value) hclsyntax.Expression {
 	if expression == nil {
 		return nil
 	}
@@ -901,8 +992,7 @@ func (attr *Attribute) VerticesReferenced(b *Block) []VertexReference {
 			continue
 		}
 
-		isProviderReference := (usesProviderConfiguration(b) && attr.Name() == "provider") || (b.Type() == "module" && attr.Name() == "providers")
-
+		isProviderReference := usesProviderConfiguration(b) && attr.Name() == "provider"
 		if isProviderReference {
 			key = fmt.Sprintf("provider.%s", strings.TrimSuffix(key, "."))
 		}
@@ -978,7 +1068,24 @@ func (attr *Attribute) referencesFromExpression(expression hcl.Expression) []*Re
 		}
 		return refs
 	case *hclsyntax.ObjectConsKeyExpr:
-		refs = append(refs, attr.referencesFromExpression(t.Wrapped)...)
+		// If the traversal is of length one it is treated as a string by Terraform.
+		// Otherwise it could be a reference. For example:
+		//
+		// providers = {
+		//   aws = aws.alias
+		// }
+		//
+		// In this case the traversal of the key expression would be of length 1 and
+		// we would treat it as a string.
+		//
+		// TODO: Although this helps, I think we still need some way of totally ignoring keys for
+		// the providers attribute of module calls since they can contain a '.' and therefore have
+		// a traversal, but are a special case that should be treated as strings.
+		wrapped, ok := t.Wrapped.(*hclsyntax.ScopeTraversalExpr)
+		if ok && len(wrapped.Traversal) > 1 {
+			refs = append(refs, attr.referencesFromExpression(t.Wrapped)...)
+		}
+
 		return refs
 	case *hclsyntax.SplatExpr:
 		refs = append(refs, attr.referencesFromExpression(t.Source)...)
@@ -1222,13 +1329,27 @@ func toRelativeTraversal(traversal hcl.Traversal) hcl.Traversal {
 	return ret
 }
 
+func traversalAsString(traversal hcl.Traversal) string {
+	buf := bytes.Buffer{}
+	for _, tr := range traversal {
+		switch step := tr.(type) {
+		case hcl.TraverseRoot:
+			buf.WriteString(step.Name)
+		case hcl.TraverseAttr:
+			buf.WriteString(".")
+			buf.WriteString(step.Name)
+		}
+	}
+	return buf.String()
+}
+
 func shouldSkipRef(block *Block, attr *Attribute, key string) bool {
 	if key == "count.index" || key == "each.key" || key == "each.value" {
 		return true
 	}
 
 	// Provider references can come through as `aws.`
-	isProviderReference := (usesProviderConfiguration(block) && attr.Name() == "provider") || (block.Type() == "module" && attr.Name() == "providers")
+	isProviderReference := usesProviderConfiguration(block) && attr.Name() == "provider"
 	if !isProviderReference && strings.HasSuffix(key, ".") {
 		return true
 	}
