@@ -205,13 +205,12 @@ func OptionWithRawCtyInput(input cty.Value) (op Option) {
 
 // OptionWithRemoteVarLoader accepts Terraform Cloud/Enterprise host and token
 // values to load remote execution variables.
-func OptionWithRemoteVarLoader(host, token, localWorkspace string) Option {
+func OptionWithRemoteVarLoader(host, token, localWorkspace string, loaderOpts ...RemoteVariablesLoaderOption) Option {
 	return func(p *Parser) {
 		if host == "" || token == "" {
 			return
 		}
 
-		var loaderOpts []RemoteVariablesLoaderOption
 		if p.newSpinner != nil {
 			loaderOpts = append(loaderOpts, RemoteVariablesLoaderWithSpinner(p.newSpinner))
 		}
@@ -266,6 +265,7 @@ func OptionGraphEvaluator() Option {
 
 type DetectedProject interface {
 	ProjectName() string
+	EnvName() string
 	RelativePath() string
 	TerraformVarFiles() []string
 	YAML() string
@@ -491,6 +491,15 @@ func (p *Parser) ProjectName() string {
 	return name
 }
 
+// EnvName returns the module suffix of the parser (normally the environment name).
+func (p *Parser) EnvName() string {
+	if p.moduleSuffix != "" {
+		return p.moduleSuffix
+	}
+
+	return p.ProjectName()
+}
+
 // TerraformVarFiles returns the list of terraform var files that the parser
 // will use to load variables from.
 func (p *Parser) TerraformVarFiles() []string {
