@@ -10,6 +10,7 @@ import (
 	"github.com/jedib0t/go-pretty/v6/text"
 	"github.com/shopspring/decimal"
 
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/ui"
 )
 
@@ -45,6 +46,8 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 		s += projectTitle(project)
 		s += "\n"
 
+		sortResources(project.Diff.Resources, "")
+
 		for _, diffResource := range project.Diff.Resources {
 			oldResource := findResourceByName(project.PastBreakdown.Resources, diffResource.Name)
 			newResource := findResourceByName(project.Breakdown.Resources, diffResource.Name)
@@ -93,12 +96,12 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 	hasDiffProjects := len(noDiffProjects)+len(erroredProjects) != len(out.Projects)
 
 	if hasDiffProjects {
-		s += fmt.Sprintf("Key: %s changed, %s added, %s removed",
+		keyStr := fmt.Sprintf("Key: * usage cost, %s changed, %s added, %s removed",
 			opChar(UPDATED),
 			opChar(ADDED),
 			opChar(REMOVED),
 		)
-		s += "\n"
+		s = keyStr + "\n\n" + s + keyStr + "\n"
 	}
 
 	if len(noDiffProjects) > 0 && opts.ShowSkipped {
@@ -113,6 +116,16 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 		s += "──────────────────────────────────"
 	}
 
+	if out.Metadata.UsageApiEnabled {
+		// for now only show the new usage-costs-including comment if the usage api has been enabled
+		// once we have all the other usage cost stuff done this will replace the old comment template
+		if hasDiffProjects {
+			s += "\n"
+			s += usageCostsMessage(out, false)
+			s += "\n"
+		}
+	}
+
 	unsupportedMsg := out.summaryMessage(opts.ShowSkipped)
 	if unsupportedMsg != "" {
 		s += "\n"
@@ -152,6 +165,44 @@ func projectTitle(project Project) string {
 }
 
 func tableForDiff(out Root, opts Options) string {
+	if out.Metadata.UsageApiEnabled {
+		// for now only show the new usage-costs in the table if the usage api has been enabled
+		// once we have all the other usage cost stuff done this will replace the old table
+		t := table.NewWriter()
+		t.SetStyle(table.StyleBold)
+		t.Style().Format.Header = text.FormatDefault
+		t.AppendHeader(table.Row{
+			"Changed project",
+			"Baseline cost",
+			"Usage cost",
+			"Total change",
+		})
+
+		t.SetColumnConfigs([]table.ColumnConfig{
+			{Name: "Changed project", WidthMin: 50},
+			{Name: "Baseline cost", WidthMin: 10, Align: text.AlignRight},
+			{Name: "Usage cost", WidthMin: 10, Align: text.AlignRight},
+			{Name: "Total change", WidthMin: 10, Align: text.AlignRight},
+		})
+
+		for _, project := range out.Projects {
+			if !showProject(project, opts, false) {
+				continue
+			}
+
+			t.AppendRow(
+				table.Row{
+					truncateMiddle(project.Name, 64, "..."),
+					formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyBaselineCost(), project.Breakdown.TotalMonthlyBaselineCost(), false, true),
+					formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyUsageCost, project.Breakdown.TotalMonthlyUsageCost, false, true),
+					formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyCost, project.Breakdown.TotalMonthlyCost, false, false),
+				},
+			)
+
+		}
+
+		return t.Render()
+	}
 	t := table.NewWriter()
 	t.SetStyle(table.StyleBold)
 	t.Style().Format.Header = text.FormatDefault
@@ -175,7 +226,7 @@ func tableForDiff(out Root, opts Options) string {
 		t.AppendRow(
 			table.Row{
 				truncateMiddle(project.Name, 64, "..."),
-				formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyCost, project.Breakdown.TotalMonthlyCost, false),
+				formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyCost, project.Breakdown.TotalMonthlyCost, false, false),
 				formatCost(out.Currency, project.Breakdown.TotalMonthlyCost),
 			},
 		)
@@ -234,6 +285,10 @@ func resourceToDiff(currency string, diffResource Resource, oldResource *Resourc
 			newComponent = findMatchingCostComponent(newResource.CostComponents, diffComponent.Name)
 		}
 
+		if zeroDiffComponent(diffComponent, oldComponent, newComponent, diffComponent.Name) {
+			continue
+		}
+
 		s += "\n"
 		s += ui.Indent(costComponentToDiff(currency, diffComponent, oldComponent, newComponent), "    ")
 	}
@@ -249,6 +304,10 @@ func resourceToDiff(currency string, diffResource Resource, oldResource *Resourc
 			newSubResource = findResourceByName(newResource.SubResources, diffSubResource.Name)
 		}
 
+		if zeroDiffResource(diffSubResource, oldSubResource, newSubResource, diffResource.Name) {
+			continue
+		}
+
 		s += "\n"
 		s += ui.Indent(resourceToDiff(currency, diffSubResource, oldSubResource, newSubResource, false), "    ")
 	}
@@ -256,6 +315,64 @@ func resourceToDiff(currency string, diffResource Resource, oldResource *Resourc
 	return s
 }
 
+func zeroDiffComponent(diff CostComponent, old, new *CostComponent, resourceName string) bool {
+	if diff.MonthlyQuantity == nil || !diff.MonthlyQuantity.IsZero() {
+		return false
+	}
+	if old != nil && (old.MonthlyQuantity == nil || !old.MonthlyQuantity.IsZero()) {
+		return false
+	}
+	if new != nil && (new.MonthlyQuantity == nil || !new.MonthlyQuantity.IsZero()) {
+		return false
+	}
+
+	logging.Logger.Debug().Msgf("Hiding diff with zero usage: %s '%s'", resourceName, diff.Name)
+	return true
+}
+
+func zeroDiffResource(diff Resource, old, new *Resource, resourceName string) bool {
+	for _, cc := range diff.CostComponents {
+		if cc.MonthlyQuantity == nil || !cc.MonthlyQuantity.IsZero() {
+			return false
+		}
+	}
+
+	if old != nil {
+		for _, cc := range old.CostComponents {
+			if cc.MonthlyQuantity == nil || !cc.MonthlyQuantity.IsZero() {
+				return false
+			}
+		}
+	}
+
+	if new != nil {
+		for _, cc := range new.CostComponents {
+			if cc.MonthlyQuantity == nil || !cc.MonthlyQuantity.IsZero() {
+				return false
+			}
+		}
+	}
+
+	for _, diffSubResource := range diff.SubResources {
+		var oldSubResource, newSubResource *Resource
+
+		if old != nil {
+			oldSubResource = findResourceByName(old.SubResources, diffSubResource.Name)
+		}
+
+		if new != nil {
+			newSubResource = findResourceByName(new.SubResources, diffSubResource.Name)
+		}
+
+		if !zeroDiffResource(diffSubResource, oldSubResource, newSubResource, diffSubResource.Name) {
+			return false
+		}
+	}
+
+	logging.Logger.Debug().Msgf("Hiding resource with no usage: %s.%s", resourceName, diff.Name)
+	return true
+}
+
 func costComponentToDiff(currency string, diffComponent CostComponent, oldComponent *CostComponent, newComponent *CostComponent) string {
 	s := ""
 
@@ -266,16 +383,18 @@ func costComponentToDiff(currency string, diffComponent CostComponent, oldCompon
 		op = REMOVED
 	}
 
-	var oldCost, newCost, oldPrice, newPrice *decimal.Decimal
+	var oldCost, newCost, oldPrice, newPrice, oldQuantity, newQuantity *decimal.Decimal
 
 	if oldComponent != nil {
 		oldCost = oldComponent.MonthlyCost
 		oldPrice = &oldComponent.Price
+		oldQuantity = oldComponent.MonthlyQuantity
 	}
 
 	if newComponent != nil {
 		newCost = newComponent.MonthlyCost
 		newPrice = &newComponent.Price
+		newQuantity = newComponent.MonthlyQuantity
 	}
 
 	s += fmt.Sprintf("%s %s\n", opChar(op), colorizeDiffName(diffComponent.Name))
@@ -288,9 +407,18 @@ func costComponentToDiff(currency string, diffComponent CostComponent, oldCompon
 			formatPriceChangeDetails(currency, oldPrice, newPrice),
 		)
 	} else {
-		s += fmt.Sprintf("  %s%s\n",
+		usageQuantity := ""
+		if diffComponent.UsageBased && diffComponent.MonthlyQuantity != nil {
+			usageQuantity = fmt.Sprintf(", %s%s*",
+				formatQuantityChange(diffComponent.MonthlyQuantity, diffComponent.Unit),
+				ui.FaintString(formatQuantityChangeDetails(oldQuantity, newQuantity)),
+			)
+		}
+
+		s += fmt.Sprintf("  %s%s%s\n",
 			formatCostChange(currency, diffComponent.MonthlyCost),
 			ui.FaintString(formatCostChangeDetails(currency, oldCost, newCost)),
+			usageQuantity,
 		)
 	}
 
@@ -343,6 +471,23 @@ func findMatchingCostComponent(costComponents []CostComponent, name string) *Cos
 	return nil
 }
 
+func formatQuantityChange(d *decimal.Decimal, unit string) string {
+	if d == nil {
+		return ""
+	}
+
+	abs := d.Abs()
+	return fmt.Sprintf("%s%s %s", getSym(*d), formatQuantity(&abs), unit)
+}
+
+func formatQuantityChangeDetails(old *decimal.Decimal, new *decimal.Decimal) string {
+	if old == nil || new == nil {
+		return ""
+	}
+
+	return fmt.Sprintf(" (%s → %s)", formatQuantity(old), formatQuantity(new))
+}
+
 func formatCostChange(currency string, d *decimal.Decimal) string {
 	if d == nil {
 		return ""
