@@ -26,6 +26,11 @@ type Metadata struct {
 	VCSPullRequestLabels []string `json:"vcsPullRequestLabels,omitempty"`
 	VCSPipelineRunID     string   `json:"vcsPipelineRunId,omitempty"`
 	VCSPullRequestID     string   `json:"vcsPullRequestId,omitempty"`
+
+	UsageApiEnabled        bool   `json:"usageApiEnabled,omitempty"`
+	UsageFilePath          string `json:"usageFilePath,omitempty"`
+	ConfigFilePath         string `json:"configFilePath,omitempty"`
+	ConfigFileHasUsageFile bool   `json:"configFileHasUsageFile,omitempty"`
 }
 
 // NewMetadata returns a Metadata struct filled with information built from the RunContext.
@@ -55,5 +60,21 @@ func NewMetadata(ctx *config.RunContext) Metadata {
 		m.VCSPipelineRunID = ctx.VCSMetadata.Pipeline.ID
 	}
 
+	if ctx.Config.UsageAPIEndpoint != "" {
+		m.UsageApiEnabled = true
+	}
+	if ctx.Config.UsageFilePath != "" {
+		m.UsageFilePath = ctx.Config.UsageFilePath
+	}
+	if ctx.Config.ConfigFilePath != "" {
+		m.ConfigFilePath = ctx.Config.ConfigFilePath
+		for _, p := range ctx.Config.Projects {
+			if p.UsageFile != "" {
+				m.ConfigFileHasUsageFile = true
+				break
+			}
+		}
+	}
+
 	return m
 }
