@@ -22,23 +22,26 @@ import (
 var outputVersion = "0.2"
 
 type Root struct {
-	Version              string           `json:"version"`
-	Metadata             Metadata         `json:"metadata"`
-	RunID                string           `json:"runId,omitempty"`
-	ShareURL             string           `json:"shareUrl,omitempty"`
-	CloudURL             string           `json:"cloudUrl,omitempty"`
-	Currency             string           `json:"currency"`
-	Projects             Projects         `json:"projects"`
-	TotalHourlyCost      *decimal.Decimal `json:"totalHourlyCost"`
-	TotalMonthlyCost     *decimal.Decimal `json:"totalMonthlyCost"`
-	PastTotalHourlyCost  *decimal.Decimal `json:"pastTotalHourlyCost"`
-	PastTotalMonthlyCost *decimal.Decimal `json:"pastTotalMonthlyCost"`
-	DiffTotalHourlyCost  *decimal.Decimal `json:"diffTotalHourlyCost"`
-	DiffTotalMonthlyCost *decimal.Decimal `json:"diffTotalMonthlyCost"`
-	TimeGenerated        time.Time        `json:"timeGenerated"`
-	Summary              *Summary         `json:"summary"`
-	FullSummary          *Summary         `json:"-"`
-	IsCIRun              bool             `json:"-"`
+	Version                   string           `json:"version"`
+	Metadata                  Metadata         `json:"metadata"`
+	RunID                     string           `json:"runId,omitempty"`
+	ShareURL                  string           `json:"shareUrl,omitempty"`
+	CloudURL                  string           `json:"cloudUrl,omitempty"`
+	Currency                  string           `json:"currency"`
+	Projects                  Projects         `json:"projects"`
+	TotalHourlyCost           *decimal.Decimal `json:"totalHourlyCost"`
+	TotalMonthlyCost          *decimal.Decimal `json:"totalMonthlyCost"`
+	TotalMonthlyUsageCost     *decimal.Decimal `json:"totalMonthlyUsageCost,omitempty"`
+	PastTotalHourlyCost       *decimal.Decimal `json:"pastTotalHourlyCost"`
+	PastTotalMonthlyCost      *decimal.Decimal `json:"pastTotalMonthlyCost"`
+	PastTotalMonthlyUsageCost *decimal.Decimal `json:"pastTotalMonthlyUsageCost,omitempty"`
+	DiffTotalHourlyCost       *decimal.Decimal `json:"diffTotalHourlyCost"`
+	DiffTotalMonthlyCost      *decimal.Decimal `json:"diffTotalMonthlyCost"`
+	DiffTotalMonthlyUsageCost *decimal.Decimal `json:"diffTotalMonthlyUsageCost,omitempty"`
+	TimeGenerated             time.Time        `json:"timeGenerated"`
+	Summary                   *Summary         `json:"summary"`
+	FullSummary               *Summary         `json:"-"`
+	IsCIRun                   bool             `json:"-"`
 }
 
 // HasUnsupportedResources returns if the summary has any unsupported resources.
@@ -101,16 +104,17 @@ func convertOutputResources(outResources []Resource, skip bool) []*schema.Resour
 
 	for i, resource := range outResources {
 		resources[i] = &schema.Resource{
-			Name:           resource.Name,
-			IsSkipped:      skip,
-			Metadata:       convertMetadata(resource.Metadata),
-			CostComponents: convertCostComponents(resource.CostComponents),
-			ActualCosts:    convertActualCosts(resource.ActualCosts),
-			SubResources:   convertOutputResources(resource.SubResources, skip),
-			Tags:           resource.Tags,
-			HourlyCost:     resource.HourlyCost,
-			MonthlyCost:    resource.MonthlyCost,
-			ResourceType:   resource.ResourceType,
+			Name:             resource.Name,
+			IsSkipped:        skip,
+			Metadata:         convertMetadata(resource.Metadata),
+			CostComponents:   convertCostComponents(resource.CostComponents),
+			ActualCosts:      convertActualCosts(resource.ActualCosts),
+			SubResources:     convertOutputResources(resource.SubResources, skip),
+			Tags:             resource.Tags,
+			HourlyCost:       resource.HourlyCost,
+			MonthlyCost:      resource.MonthlyCost,
+			MonthlyUsageCost: resource.MonthlyUsageCost,
+			ResourceType:     resource.ResourceType,
 		}
 	}
 
@@ -129,6 +133,7 @@ func convertCostComponents(outComponents []CostComponent) []*schema.CostComponen
 			MonthlyCost:     c.MonthlyCost,
 			HourlyQuantity:  c.HourlyQuantity,
 			MonthlyQuantity: c.MonthlyQuantity,
+			UsageBased:      c.UsageBased,
 		}
 		sc.SetPrice(c.Price)
 
@@ -233,10 +238,11 @@ func (p *Project) LabelWithMetadata() string {
 }
 
 type Breakdown struct {
-	Resources        []Resource       `json:"resources"`
-	FreeResources    []Resource       `json:"freeResources,omitempty"`
-	TotalHourlyCost  *decimal.Decimal `json:"totalHourlyCost"`
-	TotalMonthlyCost *decimal.Decimal `json:"totalMonthlyCost"`
+	Resources             []Resource       `json:"resources"`
+	FreeResources         []Resource       `json:"freeResources,omitempty"`
+	TotalHourlyCost       *decimal.Decimal `json:"totalHourlyCost"`
+	TotalMonthlyCost      *decimal.Decimal `json:"totalMonthlyCost"`
+	TotalMonthlyUsageCost *decimal.Decimal `json:"totalMonthlyUsageCost"`
 }
 
 // HasResources returns true if the breakdown has any resources or free resources.
@@ -245,6 +251,18 @@ func (b *Breakdown) HasResources() bool {
 	return len(b.Resources) > 0 || len(b.FreeResources) > 0
 }
 
+func (b *Breakdown) TotalMonthlyBaselineCost() *decimal.Decimal {
+	if b.TotalMonthlyCost == nil {
+		return nil
+	}
+
+	if b.TotalMonthlyUsageCost == nil {
+		return b.TotalMonthlyCost
+	}
+
+	return decimalPtr(b.TotalMonthlyCost.Sub(*b.TotalMonthlyUsageCost))
+}
+
 type CostComponent struct {
 	Name            string           `json:"name"`
 	Unit            string           `json:"unit"`
@@ -253,6 +271,7 @@ type CostComponent struct {
 	Price           decimal.Decimal  `json:"price"`
 	HourlyCost      *decimal.Decimal `json:"hourlyCost"`
 	MonthlyCost     *decimal.Decimal `json:"monthlyCost"`
+	UsageBased      bool             `json:"usageBased,omitempty"`
 }
 
 type ActualCosts struct {
@@ -263,15 +282,16 @@ type ActualCosts struct {
 }
 
 type Resource struct {
-	Name           string                 `json:"name"`
-	ResourceType   string                 `json:"resourceType,omitempty"`
-	Tags           *map[string]string     `json:"tags,omitempty"`
-	Metadata       map[string]interface{} `json:"metadata"`
-	HourlyCost     *decimal.Decimal       `json:"hourlyCost,omitempty"`
-	MonthlyCost    *decimal.Decimal       `json:"monthlyCost,omitempty"`
-	CostComponents []CostComponent        `json:"costComponents,omitempty"`
-	ActualCosts    []ActualCosts          `json:"actualCosts,omitempty"`
-	SubResources   []Resource             `json:"subresources,omitempty"`
+	Name             string                 `json:"name"`
+	ResourceType     string                 `json:"resourceType,omitempty"`
+	Tags             *map[string]string     `json:"tags,omitempty"`
+	Metadata         map[string]interface{} `json:"metadata"`
+	HourlyCost       *decimal.Decimal       `json:"hourlyCost,omitempty"`
+	MonthlyCost      *decimal.Decimal       `json:"monthlyCost,omitempty"`
+	MonthlyUsageCost *decimal.Decimal       `json:"monthlyUsageCost,omitempty"`
+	CostComponents   []CostComponent        `json:"costComponents,omitempty"`
+	ActualCosts      []ActualCosts          `json:"actualCosts,omitempty"`
+	SubResources     []Resource             `json:"subresources,omitempty"`
 }
 
 type Summary struct {
@@ -460,13 +480,14 @@ func outputBreakdown(c *config.Config, resources []*schema.Resource) *Breakdown
 	sortResources(supportedResources, "")
 	sortResources(freeResources, "")
 
-	totalMonthlyCost, totalHourlyCost := calculateTotalCosts(supportedResources)
+	totalHourlyCost, totalMonthlyCost, totalMonthlyUsageCost := calculateTotalCosts(supportedResources)
 
 	return &Breakdown{
-		Resources:        supportedResources,
-		FreeResources:    freeResources,
-		TotalHourlyCost:  totalMonthlyCost,
-		TotalMonthlyCost: totalHourlyCost,
+		Resources:             supportedResources,
+		FreeResources:         freeResources,
+		TotalHourlyCost:       totalHourlyCost,
+		TotalMonthlyCost:      totalMonthlyCost,
+		TotalMonthlyUsageCost: totalMonthlyUsageCost,
 	}
 }
 func outputResource(r *schema.Resource) Resource {
@@ -489,15 +510,16 @@ func newResource(r *schema.Resource, comps []CostComponent, actualCosts []Actual
 	}
 
 	return Resource{
-		Name:           r.Name,
-		ResourceType:   r.ResourceType,
-		Metadata:       metadata,
-		Tags:           r.Tags,
-		HourlyCost:     r.HourlyCost,
-		MonthlyCost:    r.MonthlyCost,
-		CostComponents: comps,
-		ActualCosts:    actualCosts,
-		SubResources:   subresources,
+		Name:             r.Name,
+		ResourceType:     r.ResourceType,
+		Metadata:         metadata,
+		Tags:             r.Tags,
+		HourlyCost:       r.HourlyCost,
+		MonthlyCost:      r.MonthlyCost,
+		MonthlyUsageCost: r.MonthlyUsageCost,
+		CostComponents:   comps,
+		ActualCosts:      actualCosts,
+		SubResources:     subresources,
 	}
 }
 
@@ -512,6 +534,7 @@ func outputCostComponents(costComponents []*schema.CostComponent) []CostComponen
 			Price:           c.UnitMultiplierPrice(),
 			HourlyCost:      c.HourlyCost,
 			MonthlyCost:     c.MonthlyCost,
+			UsageBased:      c.UsageBased,
 		})
 	}
 	return comps
@@ -531,9 +554,9 @@ func outputActualCosts(actualCosts []*schema.ActualCosts) []ActualCosts {
 }
 
 func ToOutputFormat(c *config.Config, projects []*schema.Project) (Root, error) {
-	var totalMonthlyCost, totalHourlyCost,
-		pastTotalMonthlyCost, pastTotalHourlyCost,
-		diffTotalMonthlyCost, diffTotalHourlyCost *decimal.Decimal
+	var totalMonthlyCost, totalHourlyCost, totalMonthlyUsageCost,
+		pastTotalMonthlyCost, pastTotalHourlyCost, pastTotalMonthlyUsageCost,
+		diffTotalMonthlyCost, diffTotalHourlyCost, diffTotalMonthlyUsageCost *decimal.Decimal
 
 	outProjects := make([]Project, 0, len(projects))
 	summaries := make([]*Summary, 0, len(projects))
@@ -558,6 +581,13 @@ func ToOutputFormat(c *config.Config, projects []*schema.Project) (Root, error)
 				}
 				totalMonthlyCost = decimalPtr(totalMonthlyCost.Add(*breakdown.TotalMonthlyCost))
 			}
+
+			if breakdown.TotalMonthlyUsageCost != nil {
+				if totalMonthlyUsageCost == nil {
+					totalMonthlyUsageCost = decimalPtr(decimal.Zero)
+				}
+				totalMonthlyUsageCost = decimalPtr(totalMonthlyUsageCost.Add(*breakdown.TotalMonthlyUsageCost))
+			}
 		}
 
 		if project.HasDiff {
@@ -578,6 +608,13 @@ func ToOutputFormat(c *config.Config, projects []*schema.Project) (Root, error)
 					}
 					pastTotalMonthlyCost = decimalPtr(pastTotalMonthlyCost.Add(*pastBreakdown.TotalMonthlyCost))
 				}
+
+				if pastBreakdown.TotalMonthlyUsageCost != nil {
+					if pastTotalMonthlyUsageCost == nil {
+						pastTotalMonthlyUsageCost = decimalPtr(decimal.Zero)
+					}
+					pastTotalMonthlyUsageCost = decimalPtr(pastTotalMonthlyUsageCost.Add(*pastBreakdown.TotalMonthlyUsageCost))
+				}
 			}
 
 			if diff != nil {
@@ -594,6 +631,13 @@ func ToOutputFormat(c *config.Config, projects []*schema.Project) (Root, error)
 					}
 					diffTotalMonthlyCost = decimalPtr(diffTotalMonthlyCost.Add(*diff.TotalMonthlyCost))
 				}
+
+				if diff.TotalMonthlyUsageCost != nil {
+					if diffTotalMonthlyUsageCost == nil {
+						diffTotalMonthlyUsageCost = decimalPtr(decimal.Zero)
+					}
+					diffTotalMonthlyUsageCost = decimalPtr(diffTotalMonthlyUsageCost.Add(*diff.TotalMonthlyUsageCost))
+				}
 			}
 		}
 
@@ -631,17 +675,20 @@ func ToOutputFormat(c *config.Config, projects []*schema.Project) (Root, error)
 	}
 
 	out := Root{
-		Version:              outputVersion,
-		Projects:             outProjects,
-		TotalHourlyCost:      totalHourlyCost,
-		TotalMonthlyCost:     totalMonthlyCost,
-		PastTotalHourlyCost:  pastTotalHourlyCost,
-		PastTotalMonthlyCost: pastTotalMonthlyCost,
-		DiffTotalHourlyCost:  diffTotalHourlyCost,
-		DiffTotalMonthlyCost: diffTotalMonthlyCost,
-		TimeGenerated:        time.Now().UTC(),
-		Summary:              MergeSummaries(summaries),
-		FullSummary:          MergeSummaries(fullSummaries),
+		Version:                   outputVersion,
+		Projects:                  outProjects,
+		TotalHourlyCost:           totalHourlyCost,
+		TotalMonthlyCost:          totalMonthlyCost,
+		TotalMonthlyUsageCost:     totalMonthlyUsageCost,
+		PastTotalHourlyCost:       pastTotalHourlyCost,
+		PastTotalMonthlyCost:      pastTotalMonthlyCost,
+		PastTotalMonthlyUsageCost: pastTotalMonthlyUsageCost,
+		DiffTotalHourlyCost:       diffTotalHourlyCost,
+		DiffTotalMonthlyCost:      diffTotalMonthlyCost,
+		DiffTotalMonthlyUsageCost: diffTotalMonthlyUsageCost,
+		TimeGenerated:             time.Now().UTC(),
+		Summary:                   MergeSummaries(summaries),
+		FullSummary:               MergeSummaries(fullSummaries),
 	}
 
 	return out, nil
@@ -674,24 +721,6 @@ func (r *Root) summaryMessage(showSkipped bool) string {
 		} else {
 			msg += fmt.Sprintf("\n∙ %d were estimated", *r.Summary.TotalSupportedResources)
 		}
-
-		allUsageBased := *r.Summary.TotalUsageBasedResources == *r.Summary.TotalSupportedResources
-
-		if r.Summary.TotalUsageBasedResources != nil && *r.Summary.TotalUsageBasedResources > 0 {
-			usageBasedCount := "1 of which"
-			if allUsageBased {
-				usageBasedCount = "it includes"
-			}
-
-			if *r.Summary.TotalUsageBasedResources > 1 {
-				usageBasedCount = fmt.Sprintf("%d of which include", *r.Summary.TotalUsageBasedResources)
-				if allUsageBased {
-					usageBasedCount = "all of which include"
-				}
-			}
-
-			msg += fmt.Sprintf(", %s usage-based costs, see %s", usageBasedCount, ui.SecondaryLinkString("https://infracost.io/usage-file"))
-		}
 	}
 
 	if r.Summary.TotalNoPriceResources != nil && *r.Summary.TotalNoPriceResources > 0 {
@@ -700,13 +729,6 @@ func (r *Root) summaryMessage(showSkipped bool) string {
 		} else {
 			msg += fmt.Sprintf("\n∙ %d were free", *r.Summary.TotalNoPriceResources)
 		}
-
-		if showSkipped {
-			msg += ":"
-			msg += formatCounts(r.Summary.NoPriceResourceCounts)
-		} else {
-			msg += seeDetailsMessage
-		}
 	}
 
 	if r.Summary.TotalUnsupportedResources != nil && *r.Summary.TotalUnsupportedResources > 0 {
@@ -913,9 +935,10 @@ func MergeSummaries(summaries []*Summary) *Summary {
 	return merged
 }
 
-func calculateTotalCosts(resources []Resource) (*decimal.Decimal, *decimal.Decimal) {
+func calculateTotalCosts(resources []Resource) (*decimal.Decimal, *decimal.Decimal, *decimal.Decimal) {
 	totalHourlyCost := decimalPtr(decimal.Zero)
 	totalMonthlyCost := decimalPtr(decimal.Zero)
+	totalMonthlyUsageCost := decimalPtr(decimal.Zero)
 
 	for _, r := range resources {
 		if r.HourlyCost != nil {
@@ -933,25 +956,40 @@ func calculateTotalCosts(resources []Resource) (*decimal.Decimal, *decimal.Decim
 			totalMonthlyCost = decimalPtr(totalMonthlyCost.Add(*r.MonthlyCost))
 		}
 
+		if r.MonthlyUsageCost != nil {
+			if totalMonthlyUsageCost == nil {
+				totalMonthlyUsageCost = decimalPtr(decimal.Zero)
+			}
+
+			totalMonthlyUsageCost = decimalPtr(totalMonthlyUsageCost.Add(*r.MonthlyUsageCost))
+
+		}
+
 	}
 
-	return totalHourlyCost, totalMonthlyCost
+	return totalHourlyCost, totalMonthlyCost, totalMonthlyUsageCost
 }
 
 func sortResources(resources []Resource, groupKey string) {
 	sort.Slice(resources, func(i, j int) bool {
-		// If an empty group key is passed just sort by name
-		if groupKey == "" {
-			return resources[i].Name < resources[j].Name
+		// if they are in different groups, sort by group name
+		if groupKey != "" && resources[i].Metadata[groupKey] != resources[j].Metadata[groupKey] {
+			return resources[i].Metadata[groupKey].(string) < resources[j].Metadata[groupKey].(string)
 		}
 
-		// If the resources are in the same group then sort by name
-		if resources[i].Metadata[groupKey] == resources[j].Metadata[groupKey] {
-			return resources[i].Name < resources[j].Name
+		// if the costs are different, sort by cost descending
+		if resources[i].MonthlyCost == nil {
+			if resources[j].MonthlyCost != nil {
+				return false
+			}
+		} else if resources[j].MonthlyCost == nil {
+			return true
+		} else if !resources[i].MonthlyCost.Equal(*resources[j].MonthlyCost) {
+			return resources[i].MonthlyCost.GreaterThan(*resources[j].MonthlyCost)
 		}
 
-		// Sort by the group key
-		return resources[i].Metadata[groupKey].(string) < resources[j].Metadata[groupKey].(string)
+		// Sort by name
+		return resources[i].Name < resources[j].Name
 	})
 }
 
