@@ -1,7 +1,7 @@
 package aws
 
 import (
-	"github.com/awslabs/goformation/v4/cloudformation/dynamodb"
+	"github.com/awslabs/goformation/v7/cloudformation/dynamodb"
 	"github.com/rs/zerolog/log"
 
 	"github.com/infracost/infracost/internal/resources/aws"
@@ -29,17 +29,17 @@ func NewDynamoDBTable(d *schema.ResourceData, u *schema.UsageData) *schema.Resou
 	billingMode := cfr.BillingMode
 	var readCapacity int64
 	if cfr.ProvisionedThroughput != nil {
-		readCapacity = cfr.ProvisionedThroughput.ReadCapacityUnits
+		readCapacity = int64(cfr.ProvisionedThroughput.ReadCapacityUnits)
 	}
 	var writeCapacity int64
 	if cfr.ProvisionedThroughput != nil {
-		writeCapacity = cfr.ProvisionedThroughput.WriteCapacityUnits
+		writeCapacity = int64(cfr.ProvisionedThroughput.WriteCapacityUnits)
 	}
 
 	a := &aws.DynamoDBTable{
 		Address:        d.Address,
 		Region:         region,
-		BillingMode:    billingMode,
+		BillingMode:    *billingMode,
 		WriteCapacity:  &writeCapacity,
 		ReadCapacity:   &readCapacity,
 		ReplicaRegions: []string{}, // Global Tables are defined using AWS::DynamoDB::GlobalTable
@@ -47,7 +47,6 @@ func NewDynamoDBTable(d *schema.ResourceData, u *schema.UsageData) *schema.Resou
 	a.PopulateUsage(u)
 
 	resource := a.BuildResource()
-	resource.Tags = mapTags(cfr.Tags)
 
 	return resource
 }
