@@ -7,16 +7,14 @@ import (
 
 func getConfigurationRecorderItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_config_configuration_recorder",
-		RFunc: NewConfigConfigurationRecorder,
+		Name:      "aws_config_configuration_recorder",
+		CoreRFunc: NewConfigConfigurationRecorder,
 	}
 }
-func NewConfigConfigurationRecorder(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewConfigConfigurationRecorder(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.ConfigConfigurationRecorder{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
