@@ -7,12 +7,12 @@ import (
 
 func getRDSClusterInstanceRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_rds_cluster_instance",
-		RFunc: NewRDSClusterInstance,
+		Name:      "aws_rds_cluster_instance",
+		CoreRFunc: NewRDSClusterInstance,
 	}
 }
 
-func NewRDSClusterInstance(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewRDSClusterInstance(d *schema.ResourceData) schema.CoreResource {
 	piEnabled := d.Get("performance_insights_enabled").Bool()
 	piLongTerm := piEnabled && d.Get("performance_insights_retention_period").Int() > 7
 
@@ -22,10 +22,9 @@ func NewRDSClusterInstance(d *schema.ResourceData, u *schema.UsageData) *schema.
 		InstanceClass:                        d.Get("instance_class").String(),
 		IOOptimized:                          false, // IO Optimized isn't supported by terraform yet
 		Engine:                               d.Get("engine").String(),
+		Version:                              d.Get("engine_version").String(),
 		PerformanceInsightsEnabled:           piEnabled,
 		PerformanceInsightsLongTermRetention: piLongTerm,
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
