@@ -7,18 +7,16 @@ import (
 
 func getStepFunctionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_sfn_state_machine",
-		RFunc: NewSFnStateMachine,
+		Name:      "aws_sfn_state_machine",
+		CoreRFunc: NewSFnStateMachine,
 	}
 }
 
-func NewSFnStateMachine(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewSFnStateMachine(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.SFnStateMachine{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 		Type:    d.Get("type").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
