@@ -7,19 +7,18 @@ import (
 
 func getAppServiceEnvironmentRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_app_service_environment",
-		RFunc: NewAppServiceEnvironment,
+		Name:      "azurerm_app_service_environment",
+		CoreRFunc: NewAppServiceEnvironment,
 		ReferenceAttributes: []string{
 			"resource_group_name",
 		},
 	}
 }
-func NewAppServiceEnvironment(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewAppServiceEnvironment(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.AppServiceEnvironment{
 		Address:     d.Address,
 		Region:      lookupRegion(d, []string{"resource_group_name"}),
 		PricingTier: d.Get("pricing_tier").String(),
 	}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
