@@ -7,20 +7,19 @@ import (
 
 func getApplicationInsightsWebTestRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_application_insights_web_test",
-		RFunc: NewApplicationInsightsWebTest,
+		Name:      "azurerm_application_insights_web_test",
+		CoreRFunc: NewApplicationInsightsWebTest,
 		ReferenceAttributes: []string{
 			"resource_group_name",
 		},
 	}
 }
-func NewApplicationInsightsWebTest(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewApplicationInsightsWebTest(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.ApplicationInsightsWebTest{
 		Address: d.Address,
 		Region:  lookupRegion(d, []string{"resource_group_name"}),
 		Enabled: d.Get("enabled").Bool(),
 		Kind:    d.Get("kind").String(),
 	}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
