@@ -7,15 +7,14 @@ import (
 
 func getDNSPtrRecordRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_dns_ptr_record",
-		RFunc: NewDNSPtrRecord,
+		Name:      "azurerm_dns_ptr_record",
+		CoreRFunc: NewDNSPtrRecord,
 		ReferenceAttributes: []string{
 			"resource_group_name",
 		},
 	}
 }
-func NewDNSPtrRecord(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDNSPtrRecord(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.DNSPtrRecord{Address: d.Address, Region: lookupRegion(d, []string{"resource_group_name"})}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
