@@ -4,9 +4,10 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/infracost/infracost/internal/schema"
+	"github.com/rs/zerolog/log"
 	"github.com/shopspring/decimal"
-	log "github.com/sirupsen/logrus"
+
+	"github.com/infracost/infracost/internal/schema"
 )
 
 func GetAzureRMMariaDBServerRegistryItem() *schema.RegistryItem {
@@ -29,7 +30,7 @@ func NewAzureRMMariaDBServer(d *schema.ResourceData, u *schema.UsageData) *schem
 		family = strings.Split(sku, "_")[1]
 		cores = strings.Split(sku, "_")[2]
 	} else {
-		log.Warnf("Unrecognised MariaDB SKU format for resource %s: %s", d.Address, sku)
+		log.Warn().Msgf("Unrecognised MariaDB SKU format for resource %s: %s", d.Address, sku)
 		return nil
 	}
 
@@ -40,7 +41,7 @@ func NewAzureRMMariaDBServer(d *schema.ResourceData, u *schema.UsageData) *schem
 	}[tier]
 
 	if tierName == "" {
-		log.Warnf("Unrecognised MariaDB tier prefix for resource %s: %s", d.Address, tierName)
+		log.Warn().Msgf("Unrecognised MariaDB tier prefix for resource %s: %s", d.Address, tierName)
 		return nil
 	}
 
