@@ -162,10 +162,20 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getPrivateDnsResolverDnsForwardingRulesetRegistryItem(),
 	getMachineLearningComputeInstanceRegistryItem(),
 	getMachineLearningComputeClusterRegistryItem(),
+	getNetworkDdosProtectionPlanRegistryItem(),
+	getAppConfigurationRegistryItem(),
+	getFederatedIdentityCredentialRegistryItem(),
+	getCognitiveAccountRegistryItem(),
+	getCognitiveDeploymentRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
 var FreeResources = []string{
+	// Azure App Configuration
+	"azurerm_app_configuration_feature",
+	"azurerm_app_configuration_key",
+	// Azure AI Services
+	"azurerm_cognitive_account_customer_managed_key",
 	// Azure Api Management
 	"azurerm_api_management_api",
 	"azurerm_api_management_api_diagnostic",
