@@ -7,12 +7,12 @@ import (
 
 func getVirtualHubRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_virtual_hub",
-		RFunc: newVirtualHub,
+		Name:      "azurerm_virtual_hub",
+		CoreRFunc: newVirtualHub,
 	}
 }
 
-func newVirtualHub(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func newVirtualHub(d *schema.ResourceData) schema.CoreResource {
 	region := d.Get("region").String()
 	sku := "Basic"
 	s := d.Get("sku").String()
@@ -25,7 +25,6 @@ func newVirtualHub(d *schema.ResourceData, u *schema.UsageData) *schema.Resource
 		Region:  region,
 		SKU:     sku,
 	}
-	v.PopulateUsage(u)
 
-	return v.BuildResource()
+	return v
 }
