@@ -8,17 +8,16 @@ import (
 func getContainerRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:                "google_container_registry",
-		RFunc:               NewContainerRegistry,
+		CoreRFunc:           NewContainerRegistry,
 		ReferenceAttributes: []string{},
 	}
 }
-func NewContainerRegistry(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewContainerRegistry(d *schema.ResourceData) schema.CoreResource {
 	r := &google.ContainerRegistry{
 		Address:      d.Address,
 		Region:       d.Get("region").String(),
 		Location:     d.Get("location").String(),
 		StorageClass: d.Get("storage_class").String(),
 	}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
