@@ -70,36 +70,42 @@ type cloudfrontDistributionShieldRequestsUsage struct {
 	India        *int64 `infracost_usage:"india"`
 }
 
-var CloudfrontDistributionUsageSchema = []*schema.UsageItem{
-	{
-		Key:          "monthly_http_requests",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_http_requests", Items: cloudfrontDistributionRegionRequestsSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
-	{
-		Key:          "monthly_https_requests",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_https_requests", Items: cloudfrontDistributionRegionRequestsSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
-	{
-		Key:          "monthly_shield_requests",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_shield_requests", Items: cloudfrontDistributionShieldRequestsSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
-	{Key: "monthly_invalidation_requests", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_encryption_requests", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_log_lines", ValueType: schema.Int64, DefaultValue: 0},
-	{
-		Key:          "monthly_data_transfer_to_internet_gb",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_data_transfer_to_internet_gb", Items: cloudfrontDistributionRegionDataTransferSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
-	{
-		Key:          "monthly_data_transfer_to_origin_gb",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_data_transfer_to_origin_gb", Items: cloudfrontDistributionRegionDataTransferSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
-	{Key: "custom_ssl_certificates", ValueType: schema.Int64, DefaultValue: 0},
+func (r *CloudfrontDistribution) CoreType() string {
+	return "CloudfrontDistribution"
+}
+
+func (r *CloudfrontDistribution) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{
+			Key:          "monthly_http_requests",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_http_requests", Items: cloudfrontDistributionRegionRequestsSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+		{
+			Key:          "monthly_https_requests",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_https_requests", Items: cloudfrontDistributionRegionRequestsSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+		{
+			Key:          "monthly_shield_requests",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_shield_requests", Items: cloudfrontDistributionShieldRequestsSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+		{Key: "monthly_invalidation_requests", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_encryption_requests", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_log_lines", ValueType: schema.Int64, DefaultValue: 0},
+		{
+			Key:          "monthly_data_transfer_to_internet_gb",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_data_transfer_to_internet_gb", Items: cloudfrontDistributionRegionDataTransferSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+		{
+			Key:          "monthly_data_transfer_to_origin_gb",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_data_transfer_to_origin_gb", Items: cloudfrontDistributionRegionDataTransferSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+		{Key: "custom_ssl_certificates", ValueType: schema.Int64, DefaultValue: 0},
+	}
 }
 
 var cloudfrontDistributionRegionRequestsSchema = []*schema.UsageItem{
@@ -339,6 +345,7 @@ func (r *CloudfrontDistribution) buildDataOutCostComponent(usageName, fromLocati
 		PriceFilter: &schema.PriceFilter{
 			StartUsageAmount: strPtr(strconv.Itoa(startUsage)),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -366,6 +373,7 @@ func (r *CloudfrontDistribution) dataOutToOriginCostComponents(regionData *cloud
 				{Key: "fromLocation", Value: strPtr(apiRegion)},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -394,6 +402,7 @@ func (r *CloudfrontDistribution) httpRequestsCostComponents(regionData *cloudfro
 				{Key: "requestType", Value: strPtr("CloudFront-Request-HTTP-Proxy")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -422,6 +431,7 @@ func (r *CloudfrontDistribution) httpsRequestsCostComponents(regionData *cloudfr
 				{Key: "requestType", Value: strPtr("CloudFront-Request-HTTPS-Proxy")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -517,6 +527,7 @@ func (r *CloudfrontDistribution) shieldRequestsCostComponents() []*schema.CostCo
 				{Key: "location", Value: strPtr(apiRegion)},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -552,6 +563,7 @@ func (r *CloudfrontDistribution) invalidationRequestsCostComponents() []*schema.
 		PriceFilter: &schema.PriceFilter{
 			StartUsageAmount: strPtr("0"),
 		},
+		UsageBased: true,
 	})
 
 	if paidQuantity != nil {
@@ -570,6 +582,7 @@ func (r *CloudfrontDistribution) invalidationRequestsCostComponents() []*schema.
 			PriceFilter: &schema.PriceFilter{
 				StartUsageAmount: strPtr("1000"),
 			},
+			UsageBased: true,
 		})
 	}
 
@@ -601,6 +614,7 @@ func (r *CloudfrontDistribution) encryptionRequestsCostComponents() []*schema.Co
 				{Key: "location", Value: strPtr("Europe")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -630,6 +644,7 @@ func (r *CloudfrontDistribution) realtimeLogsCostComponents() []*schema.CostComp
 				{Key: "operation", Value: strPtr("RealTimeLog")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
@@ -659,6 +674,7 @@ func (r *CloudfrontDistribution) customSSLCertificateCostComponents() []*schema.
 				{Key: "usagetype", Value: strPtr("SSL-Cert-Custom")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return costComponents
