@@ -16,6 +16,7 @@ type RDSClusterInstance struct {
 	Region                                       string
 	InstanceClass                                string
 	Engine                                       string
+	Version                                      string
 	IOOptimized                                  bool
 	PerformanceInsightsEnabled                   bool
 	PerformanceInsightsLongTermRetention         bool
@@ -26,12 +27,18 @@ type RDSClusterInstance struct {
 	ReservedInstancePaymentOption                *string `infracost_usage:"reserved_instance_payment_option"`
 }
 
-var RDSClusterInstanceUsageSchema = []*schema.UsageItem{
-	{Key: "monthly_cpu_credit_hrs", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "vcpu_count", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_additional_performance_insights_requests", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "reserved_instance_term", DefaultValue: "", ValueType: schema.String},
-	{Key: "reserved_instance_payment_option", DefaultValue: "", ValueType: schema.String},
+func (r *RDSClusterInstance) CoreType() string {
+	return "RDSClusterInstance"
+}
+
+func (r *RDSClusterInstance) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "monthly_cpu_credit_hrs", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "vcpu_count", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_additional_performance_insights_requests", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "reserved_instance_term", DefaultValue: "", ValueType: schema.String},
+		{Key: "reserved_instance_payment_option", DefaultValue: "", ValueType: schema.String},
+	}
 }
 
 func (r *RDSClusterInstance) PopulateUsage(u *schema.UsageData) {
@@ -121,10 +128,15 @@ func (r *RDSClusterInstance) BuildResource() *schema.Resource {
 		}
 	}
 
+	extendedSupport := extendedSupportCostComponent(r.Version, r.Region, r.Engine, r.InstanceClass)
+	if extendedSupport != nil {
+		costComponents = append(costComponents, extendedSupport)
+	}
+
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
-		UsageSchema:    RDSClusterInstanceUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
 
@@ -152,5 +164,6 @@ func (r *RDSClusterInstance) cpuCreditsCostComponent(databaseEngine, instanceFam
 				{Key: "usagetype", ValueRegex: regexPtr("CPUCredits:" + instanceFamily + "$")},
 			},
 		},
+		UsageBased: true,
 	}
 }
