@@ -4,10 +4,11 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/shopspring/decimal"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/usage"
-	"github.com/shopspring/decimal"
 )
 
 // Frontdoor struct represents Azure's Front Door network service.
@@ -37,14 +38,21 @@ type frontdoorOutboundDataTransferUsage struct {
 	Zone5MonthlyTransferGB      *float64 `infracost_usage:"india"`
 }
 
-// FrontdoorUsageSchema defines a list which represents the usage schema of Frontdoor.
-var FrontdoorUsageSchema = []*schema.UsageItem{
-	{Key: "monthly_inbound_data_transfer_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{
-		Key:          "monthly_outbound_data_transfer_gb",
-		DefaultValue: &usage.ResourceUsage{Name: "monthly_outbound_data_transfer_gb", Items: frontdoorOutboundDataUsageSchema},
-		ValueType:    schema.SubResourceUsage,
-	},
+// CoreType returns the name of this resource type
+func (r *Frontdoor) CoreType() string {
+	return "Frontdoor"
+}
+
+// UsageSchema defines a list which represents the usage schema of EventGridTopic.
+func (r *Frontdoor) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "monthly_inbound_data_transfer_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{
+			Key:          "monthly_outbound_data_transfer_gb",
+			DefaultValue: &usage.ResourceUsage{Name: "monthly_outbound_data_transfer_gb", Items: frontdoorOutboundDataUsageSchema},
+			ValueType:    schema.SubResourceUsage,
+		},
+	}
 }
 
 // frontdoorOutboundDataUsageSchema defines a nested list of outbound data
@@ -81,7 +89,7 @@ func (r *Frontdoor) BuildResource() *schema.Resource {
 
 	return &schema.Resource{
 		Name:           r.Address,
-		UsageSchema:    FrontdoorUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 		CostComponents: costComponents,
 		SubResources:   []*schema.Resource{outboundTransferSubResource},
 	}
@@ -185,6 +193,7 @@ func (r *Frontdoor) inboundDataTransferCostComponents() []*schema.CostComponent
 			PriceFilter: &schema.PriceFilter{
 				PurchaseOption: strPtr("Consumption"),
 			},
+			UsageBased: true,
 		},
 	}
 }
@@ -297,6 +306,7 @@ func (r *Frontdoor) buildOutboundDataTransferCostComponent(name, startUsage stri
 			PurchaseOption:   strPtr("Consumption"),
 			StartUsageAmount: strPtr(startUsage),
 		},
+		UsageBased: true,
 	}
 }
 
