@@ -12,8 +12,9 @@ import (
 )
 
 const (
-	sqlServerlessTier = "general purpose - serverless"
-	sqlHyperscaleTier = "hyperscale"
+	sqlServerlessTier     = "general purpose - serverless"
+	sqlHyperscaleTier     = "hyperscale"
+	sqlGeneralPurposeTier = "general purpose"
 )
 
 var (
@@ -73,11 +74,17 @@ func (r *SQLDatabase) PopulateUsage(u *schema.UsageData) {
 	resources.PopulateArgsWithUsage(r, u)
 }
 
-var SQLDatabaseUsageSchema = []*schema.UsageItem{
-	{Key: "extra_data_storage_gb", DefaultValue: 0.0, ValueType: schema.Float64},
-	{Key: "monthly_vcore_hours", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "long_term_retention_storage_gb", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "backup_storage_gb", DefaultValue: 0, ValueType: schema.Int64},
+func (r *SQLDatabase) CoreType() string {
+	return "SQLDatabase"
+}
+
+func (r *SQLDatabase) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "extra_data_storage_gb", DefaultValue: 0.0, ValueType: schema.Float64},
+		{Key: "monthly_vcore_hours", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "long_term_retention_storage_gb", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "backup_storage_gb", DefaultValue: 0, ValueType: schema.Int64},
+	}
 }
 
 // BuildResource builds a schema.Resource from a valid SQLDatabase.
@@ -110,7 +117,7 @@ var SQLDatabaseUsageSchema = []*schema.UsageItem{
 func (r *SQLDatabase) BuildResource() *schema.Resource {
 	return &schema.Resource{
 		Name:           r.Address,
-		UsageSchema:    SQLDatabaseUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 		CostComponents: r.costComponents(),
 	}
 }
@@ -240,9 +247,11 @@ func (r *SQLDatabase) serverlessComputeHoursCostComponents() []*schema.CostCompo
 				{Key: "meterName", ValueRegex: regexPtr("^(?!.* - Free$).*$")},
 			}),
 			PriceFilter: priceFilterConsumption,
+			UsageBased:  true,
 		},
 	}
 
+	// Zone redundancy is free for premium and business critical tiers
 	if r.ZoneRedundant {
 		costComponents = append(costComponents, &schema.CostComponent{
 			Name:            fmt.Sprintf("Zone redundancy (serverless, %s)", r.SKU),
@@ -286,7 +295,8 @@ func (r *SQLDatabase) provisionedComputeCostComponents() []*schema.CostComponent
 		},
 	}
 
-	if r.ZoneRedundant {
+	// Zone redundancy is free for premium and business critical tiers
+	if strings.EqualFold(r.Tier, sqlGeneralPurposeTier) && r.ZoneRedundant {
 		costComponents = append(costComponents, &schema.CostComponent{
 			Name:           fmt.Sprintf("Zone redundancy (provisioned, %s)", r.SKU),
 			Unit:           "hours",
@@ -348,6 +358,7 @@ func (r *SQLDatabase) longTermRetentionCostComponent() *schema.CostComponent {
 			{Key: "meterName", ValueRegex: regexPtr(fmt.Sprintf("%s Data Stored", redundancyType))},
 		}),
 		PriceFilter: priceFilterConsumption,
+		UsageBased:  true,
 	}
 }
 
@@ -374,6 +385,7 @@ func (r *SQLDatabase) pitrBackupCostComponent() *schema.CostComponent {
 			{Key: "meterName", ValueRegex: regexPtr(fmt.Sprintf("%s Data Stored", redundancyType))},
 		}),
 		PriceFilter: priceFilterConsumption,
+		UsageBased:  true,
 	}
 }
 
@@ -435,6 +447,7 @@ func mssqlExtraDataStorageCostComponent(region string, tier string, extraStorage
 			{Key: "meterName", Value: strPtr("Data Stored")},
 		}),
 		PriceFilter: priceFilterConsumption,
+		UsageBased:  true,
 	}
 }
 
@@ -482,12 +495,12 @@ func mssqlStorageCostComponent(region string, tier string, zoneRedundant bool, m
 	}
 
 	storageTier := tier
-	if strings.ToLower(storageTier) == "general purpose - serverless" {
+	if strings.EqualFold(tier, sqlServerlessTier) {
 		storageTier = "General Purpose"
 	}
 
 	skuName := storageTier
-	if zoneRedundant {
+	if (strings.EqualFold(tier, sqlGeneralPurposeTier) || strings.EqualFold(tier, sqlServerlessTier)) && zoneRedundant {
 		skuName += " Zone Redundancy"
 	}
 
