@@ -4,8 +4,9 @@ import (
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 
-	"github.com/infracost/infracost/internal/usage"
 	"github.com/shopspring/decimal"
+
+	"github.com/infracost/infracost/internal/usage"
 )
 
 type MonitoringMetricDescriptor struct {
@@ -14,9 +15,15 @@ type MonitoringMetricDescriptor struct {
 	MonthlyAPICalls         *int64 `infracost_usage:"monthly_api_calls"`
 }
 
-var MonitoringMetricDescriptorUsageSchema = []*schema.UsageItem{
-	{Key: "monthly_monitoring_data_mb", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_api_calls", ValueType: schema.Int64, DefaultValue: 0},
+func (r *MonitoringMetricDescriptor) CoreType() string {
+	return "MonitoringMetricDescriptor"
+}
+
+func (r *MonitoringMetricDescriptor) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "monthly_monitoring_data_mb", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_api_calls", ValueType: schema.Int64, DefaultValue: 0},
+	}
 }
 
 func (r *MonitoringMetricDescriptor) PopulateUsage(u *schema.UsageData) {
@@ -57,7 +64,7 @@ func (r *MonitoringMetricDescriptor) BuildResource() *schema.Resource {
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
-		UsageSchema:    MonitoringMetricDescriptorUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
 
@@ -78,6 +85,7 @@ func (r *MonitoringMetricDescriptor) monitoringDataCostComponent(name string, us
 		PriceFilter: &schema.PriceFilter{
 			StartUsageAmount: strPtr(usageTier),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -98,5 +106,6 @@ func (r *MonitoringMetricDescriptor) apiCallsCostComponent(apiCalls *decimal.Dec
 		PriceFilter: &schema.PriceFilter{
 			StartUsageAmount: strPtr("1000000"),
 		},
+		UsageBased: true,
 	}
 }
